@@ -10,10 +10,9 @@
 //!
 //! The current version of the prelude re-exports the following:
 //!
-//! * [`MemTable`] struct, which is the core table available from
-//!   this crate that acts as a table that can grow and shrink dynamically
+//! * [`DynamicTable`] struct, which is a table that can grow and shrink dynamically
 //! * [`FixedTable`] struct - available with Rust 1.51+ - provides a fixed-sized
-//!   counterpart to [`MemTable`] where the table is pre-allocated internally
+//!   counterpart to [`DynamicTable`] where the table is pre-allocated internally
 //!   using a 2D array
 //! * [`FixedRowTable`] struct, where the total rows is fixed and columns
 //!   can grow dynamically
@@ -24,9 +23,10 @@
 //! * [`iter::CellIter`] trait, which enables examining the row & column
 //!   positions of iterators over individual cells in a table as well as zip
 //!   an iterator with the position of each cell
+//! * [`list::List`] trait, which enables operations on a generic list of items
+//! * [`list::DynamicList`] struct, which is a generic list that is able to
+//!   grow and shrink dynamically without any bounds
+//! * [`list::FixedList`] struct, which is a generic list that is able to grow
+//!   and shrink within a limited bounds
 //!
-pub use crate::{
-    impls::{FixedColumnTable, FixedRowTable, FixedTable, MemTable},
-    iter::CellIter,
-    Table,
-};
+pub use crate::{impls::*, iter::CellIter, list::*, Table};
